@@ -1,4 +1,4 @@
-/*	$Id: lowdown.h,v 1.46 2017/10/08 16:38:52 kristaps Exp $ */
+/*	$Id: lowdown.h,v 1.48 2018/12/23 18:52:19 kristaps Exp $ */
 /*
  * Copyright (c) 2017 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -215,6 +215,7 @@ struct	lowdown_node {
 			hbuf alt; /* alt-text of image */
 		} rndr_image;
 		struct rndr_math {
+			hbuf text; /* equation (opaque) */
 			int displaymode;
 		} rndr_math;
 		struct rndr_blockhtml {
@@ -245,7 +246,7 @@ struct	lowdown_opts {
 #define LOWDOWN_SUPER		 0x100
 #define LOWDOWN_MATH		 0x200
 #define LOWDOWN_NOINTEM		 0x400
-#define LOWDOWN_MATHEXP		 0x1000
+/* Disabled LOWDOWN_MATHEXP	 0x1000 */
 #define LOWDOWN_NOCODEIND	 0x2000
 #define	LOWDOWN_METADATA	 0x4000
 #define	LOWDOWN_COMMONMARK	 0x8000
